Name:		blender
Version:	2.57
Release:	%mkrel 1
Summary:	A fully functional 3D modeling/rendering/animation package
Group:		Graphics
Source0:	http://download.blender.org/source/blender-%{version}.tar.gz
Patch0:		blender-2.57-localedir.patch
Patch1:		blender-2.57-error-when-missing-sse.patch
Patch2:		blender-2.57-static-lib.patch
URL:		http://www.blender.org/
License:	GPLv2+
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-buildroot
BuildRequires:	cmake >= 2.8
BuildRequires:	ffmpeg-devel
BuildRequires:	glew-devel
BuildRequires:	OpenEXR-devel
BuildRequires:	SDL-devel
BuildRequires:	libx11-devel
BuildRequires:	libxi-devel
BuildRequires:	freetype2-devel
BuildRequires:	libgomp-devel
BuildRequires:	jpeg-devel
BuildRequires:	png-devel
BuildRequires:	openjpeg-devel
BuildRequires:	openal-devel
BuildRequires:	libsamplerate-devel
BuildRequires:	sndfile-devel
BuildRequires:	tiff-devel

%description
Blender is the in-house software of a high quality animation studio.
It has proven to be an extremely fast and versatile design instrument.
The software has a personal touch, offering a unique approach to the
world of three dimensions. Blender can be used to create TV
commercials, to make technical visualizations or business graphics, to
do some morphing, or to design user interfaces. Developers can easily
build and manage complex environments. The renderer is versatile and
extremely fast. All basic animation principles (curves and keys) are
implemented.

%prep
%setup -qn %{name}-%{version}
%patch0 -p0 -b .localedir
%patch1 -p0 -b .sse
%patch2 -p0 -b .static

%build
%ifarch %{ix86}
# build non-sse flavour
%cmake -DWITH_INSTALL_PORTABLE=OFF -DWITH_PLAYER=ON \
	-DWITH_PYTHON=OFF -DWITH_PYTHON_INSTALL=OFF \
	-DWITH_BUILTIN_GLEW=OFF \
	-DWITH_CODEC_FFMPEG=ON -DWITH_CODEC_SNDFILE=ON \
	-DWITH_RAYOPTIMIZATION=OFF
%make
cd ..
mv build non-sse
%endif

#build sse flavour
%cmake -DWITH_INSTALL_PORTABLE=OFF -DWITH_PLAYER=ON \
	-DWITH_PYTHON=OFF -DWITH_PYTHON_INSTALL=OFF \
	-DWITH_BUILTIN_GLEW=OFF \
	-DWITH_CODEC_FFMPEG=ON -DWITH_CODEC_SNDFILE=ON \
	-DWITH_RAYOPTIMIZATION=ON
%make

%install
rm -rf %{buildroot}

#install sse flavour
%makeinstall_std -C build

# Install hicolor icons.
for i in 16x16 22x22 32x32 48x48 64x64 96x96 128x128 192x192 ; do
  mkdir -p %{buildroot}%{_datadir}/icons/hicolor/${i}/apps
  install -pm 0644 release/freedesktop/icons/${i}/%{name}.png \
    %{buildroot}%{_datadir}/icons/hicolor/${i}/apps/%{name}.png
done

mkdir -p %{buildroot}%{_datadir}/icons/hicolor/scalable/apps
install -pm 0644 release/freedesktop/icons/scalable/%{name}.svg \
    %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg

%ifarch %{ix86}
mv %buildroot%_bindir/%name %buildroot%_bindir/%name.sse

#install non-sse flavour
rm -fr build
mv non-sse build
%makeinstall_std -C build
mv %buildroot%_bindir/%name %buildroot%_bindir/%name.nonsse

# install wrapper
cat >> %{buildroot}%{_bindir}/blender <<EOF 
if [ -e /proc/cpuinfo ]; then
	SSE="\`cat /proc/cpuinfo | grep flags | grep sse\`"
fi

if [ "x\$SSE" == x ]; then
	%{_bindir}/%{name}.nonsse "\$@"
else
	%{_bindir}/%{name}.sse "\$@"
fi
EOF
chmod 0755 %{buildroot}%{_bindir}/blender
%endif

%find_lang %name

%clean
rm -rf %{buildroot}

%post
if [ -x %{_gconftool_bin} ]; then
   %{_gconftool_bin} --type boolean --set /desktop/gnome/thumbnailers/application@x-blender/enable true
   %{_gconftool_bin} --type string --set /desktop/gnome/thumbnailers/application@x-blender/command "blender-thumbnailer.py %u %o"
fi

%preun
if [ "$1" = "0" -a -x %{_gconftool_bin} ]; then
   %{_gconftool_bin} --unset /desktop/gnome/thumbnailers/application@x-blender/enable
   %{_gconftool_bin} --unset /desktop/gnome/thumbnailers/application@x-blender/command
fi

%files -f %name.lang
%defattr(-,root,root)
%doc release/text/*
%{_bindir}/*
%{_datadir}/applications/*.desktop
%{_datadir}/%{name}
%{_mandir}/man1/%{name}.1.*
%{_datadir}/pixmaps/blender.*
%{_iconsdir}/hicolor/*/apps/%{name}.*


%changelog
* Sat Apr 16 2011 Funda Wang <fwang@mandriva.org> 2.57-1mdv2011.0
+ Revision: 653282
- add thumbnailer for nautilus when installing
- install hicolor icons
- 2.57
- create blender


* Tue Jan 23 2007 Gustavo De Nardin <gustavodn@mandriva.com> 2.4.6-2mdv2007.0
+ Revision: 112566
- don't double package some documentation files
- install emacs mode

* Fri Jan 12 2007 Laurent Montel <lmontel@mandriva.com> 2.4.6-1mdv2007.1
+ Revision: 107768
- 2.4.6

* Tue Jan 09 2007 Laurent Montel <lmontel@mandriva.com> 2.4.6-0.rc2.1mdv2007.1
+ Revision: 106621
- 2.4.6-rc2

* Tue Dec 05 2006 Laurent Montel <lmontel@mandriva.com> 2.4.5-1mdv2007.1
+ Revision: 90681
- 2.4.5

* Tue Nov 21 2006 Laurent Montel <lmontel@mandriva.com> 2.4.4-1mdv2007.1
+ Revision: 85881
- 2.4.4

  + Gaëtan Lehmann <glehmann@mandriva.org>
    - fix fltk detection (patch 1)

* Wed Aug 02 2006 Laurent Montel <lmontel@mandriva.com> 2.4.3-2mdv2007.0
+ Revision: 42884
- New release 2.4.3 (2006/08/01)
- 2.4.3
- 2.4.2

  + Andreas Hasenack <andreas@mandriva.com>
    - renamed mdv to packages because mdv is too generic and it's hosting only packages anyway

  + Gaëtan Lehmann <glehmann@mandriva.org>
    - update release tag
    - fix vtk 5.0 detection

  + Helio Chissini de Castro <helio@mandriva.com>
    - Added the current source
    - New Cmake 2.4.1 beta. Required for current KDE 4 development
    - Added cmake on subversion. Gaetan, current maintainer was already notified and now, since kde 4 move development pro cmake and Laurent, me and Boiko will need cmake up to date

* Sat Mar 25 2006 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 2.3.4-0.20060321.2mdk
- lib -> lib64 on x86_64 - the fix in cmake is not enough

* Tue Mar 21 2006 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 2.3.4-0.20060321.1mdk
- 2.3.4 (snapshot 20060321)

* Wed Mar 15 2006 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 2.3.4-0.20060315.2mdk
- build requires

* Wed Mar 15 2006 Laurent MONTEL <lmontel@mandriva.com> 2.3.4-0.20060315.1mdk
- 2.3.4 (snapshot 20060315)

* Sun Mar 12 2006 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 2.3.4-0.20060312.1mdk
- 2.3.4 (snapshot 20060312)

* Sun Feb 12 2006 Laurent MONTEL <lmontel@mandriva.com> 2.3.3
- 2.3.3 (snapshot 20060210)

* Fri Feb 10 2006 Laurent MONTEL <lmontel@mandriva.com> 2.3.2
- 2.3.2 version (snapshot 20060209)

* Fri Feb 03 2006 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 2.2.3-3mdk
- fix kde search path

* Sun Jan 22 2006 Laurent MONTEL <lmontel@mandriva.com> 2.2.3-2mdk
- Fix spec file. I don't understand how a 2.2.2 spec file was integrate into 2.2.3 package (nobody couldn't rebuild it)

* Fri Nov 04 2005 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 2.2.2-1mdk
- New release 2.2.2

* Thu Oct 20 2005 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 2.2.1-1mdk
- New release 2.2.1

* Tue Jul 19 2005 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 2.2.0-1mdk
- 2.2.0
- make it more rpmbuildupdatable
- buildrequires ncurses-devel
- list files in bindir to be sure that ccmake is built

* Fri Jun 10 2005 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 2.0.6-3mdk
- also fix X11 lib path on x86_64

* Fri Jun 10 2005 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 2.0.6-2mdk
- fix lib path to make ccmake compile on x86_64. It should also help
  to find lib with this arch

* Wed Apr 27 2005 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 2.0.6-1mdk
- New release 2.0.6
- use mkrel

* Fri Mar 11 2005 Gaetan Lehmann <gaetan.lehmann@jouy.inra.fr> 2.0.5-2mdk
- fix some lint
- add examples in docs

* Tue Nov 23 2004 Gaetan LEHMANN <gaetan.lehmann@jouy.inra.fr> 2.0.5-1mdk
- 2.0.5

* Wed Jun 16 2004 Laurent MONTEL <lmontel@mandrakesoft.com> 1.6.7-2mdk
- Rebuild

